You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ofbiz.apache.org by do...@apache.org on 2012/12/04 22:54:35 UTC

svn commit: r1417211 - /ofbiz/trunk/framework/entity/src/org/ofbiz/entity/util/EntityListIterator.java

Author: doogie
Date: Tue Dec  4 21:54:35 2012
New Revision: 1417211

URL: http://svn.apache.org/viewvc?rev=1417211&view=rev
Log:
TYPO: s/numRetreived/numRetrieved/

Modified:
    ofbiz/trunk/framework/entity/src/org/ofbiz/entity/util/EntityListIterator.java

Modified: ofbiz/trunk/framework/entity/src/org/ofbiz/entity/util/EntityListIterator.java
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/entity/src/org/ofbiz/entity/util/EntityListIterator.java?rev=1417211&r1=1417210&r2=1417211&view=diff
==============================================================================
--- ofbiz/trunk/framework/entity/src/org/ofbiz/entity/util/EntityListIterator.java (original)
+++ ofbiz/trunk/framework/entity/src/org/ofbiz/entity/util/EntityListIterator.java Tue Dec  4 21:54:35 2012
@@ -485,13 +485,13 @@ public class EntityListIterator implemen
             list.add(this.currentGenericValue());
 
             GenericValue nextValue = null;
-            // init numRetreived to one since we have already grabbed the initial one
-            int numRetreived = 1;
+            // init numRetrieved to one since we have already grabbed the initial one
+            int numRetrieved = 1;
 
-            //number > numRetreived comparison goes first to avoid the unwanted call to next
-            while (number > numRetreived && (nextValue = this.next()) != null) {
+            //number > numRetrieved comparison goes first to avoid the unwanted call to next
+            while (number > numRetrieved && (nextValue = this.next()) != null) {
                 list.add(nextValue);
-                numRetreived++;
+                numRetrieved++;
             }
             return list;
         } catch (SQLException e) {